#' TRNG library version.
#'
#' Return the version of the TRNG C++ library embedded in the \code{rTRNG} package.
#'
#' @export
TRNG.Version <- function() {
  return("4.23.1")
}
